pub struct Name<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Name<'a>
impl<'a> Name<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn storage_offset(&self) -> u16
pub fn storage_offset(&self) -> u16
Offset to start of string storage (from start of table).
Sourcepub fn name_record(&self) -> &'a [NameRecord]
pub fn name_record(&self) -> &'a [NameRecord]
The name records where count is the number of records.
Sourcepub fn lang_tag_count(&self) -> Option<u16>
pub fn lang_tag_count(&self) -> Option<u16>
Number of language-tag records.
Sourcepub fn lang_tag_record(&self) -> Option<&'a [LangTagRecord]>
pub fn lang_tag_record(&self) -> Option<&'a [LangTagRecord]>
The language-tag records where langTagCount is the number of records.
pub fn version_byte_range(&self) -> Range<usize> ⓘ
pub fn count_byte_range(&self) -> Range<usize> ⓘ
pub fn storage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn name_record_byte_range(&self) -> Range<usize> ⓘ
pub fn lang_tag_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lang_tag_record_byte_range(&self) -> Range<usize> ⓘ